searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"Pika.html","title":"Pika","type":"module"},{"doc":"Deconstructs a Pika ID and returns it's metadata:\n\n- prefix\n- tail\n- snowflake\n- timestamp\n- prefix_record\n- epoch\n- node_id\n- seq","ref":"Pika.html#deconstruct/1","title":"Pika.deconstruct/1","type":"function"},{"doc":"Generates an ID given a prefix (which should be configured).\n\nThis function will return an `{:error, binary()}` if one of the follow conditions are met:\n\n1. The prefix isn't valid\n2. The prefix isn't configured","ref":"Pika.html#gen/1","title":"Pika.gen/1","type":"function"},{"doc":"","ref":"Pika.html#gen!/1","title":"Pika.gen!/1","type":"function"},{"doc":"Represents a decoded `Snowflake`","ref":"Pika.DecodedSnowflake.html","title":"Pika.DecodedSnowflake","type":"module"},{"doc":"`Pika.Snowflake` holds the state, generates Snowflakes, and decodes Snowflakes.\n\n`Pika.Snowflake` should be started under a `Supervisor` or `Application` before you start using\n`Pika.gen/1` or `Pika.deconstruct/1`\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [Pika.Snowflake]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n  end\nend\n```\n\nor manually in `iex`\n\n```elixir\niex(1)> Pika.Snowflake.start_link()\n{:ok, #PID<0.190.0>}\n```","ref":"Pika.Snowflake.html","title":"Pika.Snowflake","type":"module"},{"doc":"You can start `Pika.Snowflake` with a custom epoch by passing it:\n\n```elixir\nPika.Snowflake.start_link(1_650_153_600_000)\n```","ref":"Pika.Snowflake.html#module-custom-epoch","title":"Custom epoch - Pika.Snowflake","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Pika.Snowflake.html#child_spec/1","title":"Pika.Snowflake.child_spec/1","type":"function"},{"doc":"Decodes a Snowflake and returns:\n\n- timestamp\n- epoch\n- node_id\n- seq","ref":"Pika.Snowflake.html#decode/1","title":"Pika.Snowflake.decode/1","type":"function"},{"doc":"Generates a new Snowflake","ref":"Pika.Snowflake.html#generate/0","title":"Pika.Snowflake.generate/0","type":"function"},{"doc":"Generates a new Snowflake with the given `timestamp`","ref":"Pika.Snowflake.html#generate/1","title":"Pika.Snowflake.generate/1","type":"function"},{"doc":"","ref":"Pika.Snowflake.html#init/1","title":"Pika.Snowflake.init/1","type":"function"},{"doc":"Returns the current timestamp in milliseconds.","ref":"Pika.Snowflake.html#now_ts/0","title":"Pika.Snowflake.now_ts/0","type":"function"},{"doc":"","ref":"Pika.Snowflake.html#start_link/0","title":"Pika.Snowflake.start_link/0","type":"function"},{"doc":"","ref":"Pika.Snowflake.html#start_link/1","title":"Pika.Snowflake.start_link/1","type":"function"},{"doc":"# pika\n\n> Elixir implementation of Pika\n\nCombine Stripe IDs with Snowflakes you get Pika! The last ID system you'll ever need!\nCombining pragmatism with functionality","ref":"readme.html","title":"pika","type":"extras"},{"doc":"- Written in pure Elixir\n- Zero dependencies","ref":"readme.html#features","title":"Features - pika","type":"extras"},{"doc":"The package can be installed by adding `pika` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pika, \"~> 0.3\"}\n  ]\nend\n```\n\nIn your `config.exs`:\n\n```elixir\nconfig :pika,\n  prefixes: [\n    %{prefix: \"user\", description: \"User IDs\"},\n    %{prefix: \"server\", description: \"Server IDs\", secure: true},\n    # ...\n  ]\n```","ref":"readme.html#installation","title":"Installation - pika","type":"extras"},{"doc":"`Pika.Snowflake` should be started under a `Supervisor` or `Application` before you start using\n`Pika.gen/1` or `Pika.deconstruct/1`\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [Pika.Snowflake]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n  end\nend\n```\n\nSomewhere in your application:\n\n```elixir\n# ...\nPika.gen(\"user\") # or Pika.gen!(\"user\")\n\n{:ok, \"user_MjgyNDQ2NjY1OTk3MjEzNjk3\"}\n```","ref":"readme.html#example","title":"Example - pika","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}